=============
pysma library
=============

SMA Webconnect library for Python 3

See http://www.sma-solar.com for more information on the SMA solar inverters

Currently tested on Sunnyboy 1.5

Other SMA interfaces include https://sbfspot.codeplex.com/ and a Python
`adaptation <https://github.com/TD22057/T-Home/>`_

=============
Example usage
=============

See `example.py <./example.py>`_ for a basic usage and tests